@@ -8,13 +8,13 @@
 #   files (version 3 only) to Remind format.
 #
 #   This file is part of REMIND.
-#   Copyright (C) 1992-1998 by David F. Skoll
+#   Copyright (C) 1992-1998 by Dianne Skoll
 #   Copyright (C) 1999-2000 by Roaring Penguin Software Inc.
 #
 #--------------------------------------------------------------
 
 # the next line restarts using tclsh \
-exec tclsh8.5 "$0" ${1+"$@"}
+exec /usr/local/bin/tclsh8.5 "$0" ${1+"$@"}
 
 set i 0
 foreach month {January February March April May June
